@@ -1,19 +1,8 @@
-"""
-[![PyPI](https://img.shields.io/pypi/v/silbot.svg)](https://pypi.python.org/pypi/silbot)
-[![Telegram Channel](https://img.shields.io/badge/telegram_channel-@silverosp-0d86d7.svg?style=flat)](https://t.me/SilverOSp)
-
-This is a simple framework for [telegram bot API](https://core.telegram.org/bots/api).
-
-- [__Examples__](https://github.com/SilverOS/Silbot-Py/tree/master/examples)
-- [__Github__](https://github.com/SilverOS/Silbot-Py)
-- [__Download__](https://github.com/SilverOS/Silbot-Py/archive/1.1.0.zip)
-
-"""
-
-from silbot import botapi
 from silbot import update
+from silbot import botapi
 import json
 
+
 def startpool(bot : botapi.botApi,handlefunc):
     """ This is a builtin function to handle updates with getUpdates
 
@@ -35,7 +24,7 @@ def startpool(bot : botapi.botApi,handlefunc):
                     offset = up["update_id"]+1
                     thread = update.update(up,bot,handlefunc)
                     thread.start()
-        else:
+        else :
             continue
 
 
